%define major     3
%define libname   %mklibname %{name} %{major}
%define devname   %mklibname %{name} -d
%define gitdat       20210328
%define rel       14

Name:             gr-iqbal
Summary:          GNURadio block for suppressing IQ imbalance
Version:          0.39.0
Release:          %mkrel %{?gitdat:-c %{gitdat} }%{rel}
License:          GPLv3+
Group:            Communications/Radio
Url:              https://git.osmocom.org/gr-iqbal/
Source0:          https://github.com/osmocom/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:           gr-iqbal-0.38.1-mga-include_boost_bind_headers.patch

BuildRequires:    cmake
BuildRequires:    gmp-devel
BuildRequires:    gmpxx-devel
BuildRequires:    mpir-devel
BuildRequires:    mpirxx-devel
BuildRequires:    pkgconfig(gnuradio-runtime)
BuildRequires:    pkgconfig(libosmodsp)
BuildRequires:    pkgconfig(fftw3)
BuildRequires:    pkgconfig(volk)
BuildRequires:    pybind11-devel
BuildRequires:    python-gnuradio-runtime
BuildRequires:    python3-numpy-devel
BuildRequires:    gnuradio-utils
BuildRequires:    boost-devel
BuildRequires:    doxygen
BuildRequires:    graphviz

%description
This GNURadio block can suppress IQ imbalance in the RX path of
quadrature receivers.

%package -n %{libname}
Summary:          Library files for gr-iqbal
Group:            Communications/Radio

%description -n %{libname}
Library files for gr-iqbal.

%package -n %{devname}
Summary:          Development files for gr-iqbal
Group:            Communications/Radio
Requires:         %{name} = %{version}-%{release}
Provides:         %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for gr-iqbal.

%package doc
Summary:          Documentation files for gr-iqbal
Group:            Communications/Radio
BuildArch:        noarch

%description doc
Documentation files for gr-iqbalance.

%prep
%autosetup -p1 -n %{name}

%build
%cmake -DENABLE_DOXYGEN=on 

%cmake_build

%install
%cmake_install

# .desktop for Documentation package
cat > %{name}-doc.desktop << EOF
[Desktop Entry]
Version=1.0
Name=Gr-iqbalance Documentation
GenericName=Gr-iqbalance Documentation
Exec=xdg-open /usr/share/doc/%{name}/html/index.html
Icon=
Terminal=false
Type=Application
Categories=System;Documentation;X-Mageia-CrossDesktop;
EOF

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{name}-doc.desktop

# Create pkgconfig .pc file
mkdir -p %{buildroot}%{_libdir}/pkgconfig
cat <<EOF > %{buildroot}%{_libdir}/pkgconfig/gnuradio-iqbalance.pc
prefix=%{_usr}
exec_prefix=\${prefix}
libdir=\${exec_prefix}/%{_lib}
includedir=\${prefix}/include

Name: gnuradio-iqbalance
Description: gnuradio I/Q balancing
URL: https://git.osmocom.org/gr-iqbal/
Version: %{version}
Requires: gnuradio-runtime
Libs: -L\${libdir} -lgnuradio-iqbalance
Cflags: -I\${includedir}
EOF

%files
%doc AUTHORS
%{python_sitearch}/*
%{_datadir}/gnuradio/grc/blocks/*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/gnuradio/iqbalance/*.h
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libgnuradio-iqbalance.so
%{_libdir}/cmake/gnuradio/*

%files doc
%doc %{_docdir}/%{name}ance/html/*
%doc %{_docdir}/%{name}ance/xml/*
%{_datadir}/applications/%{name}-doc.desktop


%changelog
* Sun Feb 23 2025 barjac <barjac> 0.39.0-0.20210328.14.mga10
+ Revision: 2151252
- rebuild for gnuradio-3.10.12

* Mon Aug 26 2024 barjac <barjac> 0.39.0-0.20210328.13.mga10
+ Revision: 2091401
- rebuild for gnuradio-3.10.11.0

* Tue May 14 2024 barjac <barjac> 0.39.0-0.20210328.12.mga10
+ Revision: 2064216
- rebuild for gnuradio-3.10.10.0

* Wed Apr 10 2024 barjac <barjac> 0.39.0-0.20210328.11.mga10
+ Revision: 2056334
- rebuild for gnuradio-3.10.9.2

* Fri Dec 29 2023 joequant <joequant> 0.39.0-0.20210328.10.mga10
+ Revision: 2023776
- update to py3.12

* Wed Jan 25 2023 barjac <barjac> 0.39.0-0.20210328.9.mga9
+ Revision: 1936198
- rebuild for gnuradio-3.10.5.1

* Sat Sep 17 2022 barjac <barjac> 0.39.0-0.20210328.8.mga9
+ Revision: 1889553
- rebuild for gnuradio-3.10.4.0

* Fri Aug 05 2022 barjac <barjac> 0.39.0-0.20210328.7.mga9
+ Revision: 1875423
- rebuild for gnuradio-3.10.3.0

* Tue Apr 12 2022 barjac <barjac> 0.39.0-0.20210328.6.mga9
+ Revision: 1849062
- rebuild for gnuradio-3.10.2.0

* Tue Feb 22 2022 tv <tv> 0.39.0-0.20210328.5.mga9
+ Revision: 1782870
- Rebuild for python-3.10

* Fri Feb 04 2022 barjac <barjac> 0.39.0-0.20210328.4.mga9
+ Revision: 1771423
- rebuild for gnuradio-3.10.1.1

* Mon Sep 20 2021 barjac <barjac> 0.39.0-0.20210328.3.mga9
+ Revision: 1746105
- Rebuild for gnuradio-3.9.3.0-rc1

* Sat Jun 19 2021 barjac <barjac> 0.39.0-0.20210328.2.mga9
+ Revision: 1731257
- rebuild for gnuradio-3.9.2

* Sun Mar 28 2021 barjac <barjac> 0.39.0-0.20210328.1.mga9
+ Revision: 1711445
+ rebuild (emptylog)

* Sun Mar 28 2021 barjac <barjac> 0.39.0-0.20210328.0.1.mga9
+ Revision: 1711431
- new version snapshot 0.39.0
- new BRs pybind11-devel python3-numpy-devel drop BR swig
- allow for snapshots in spec

* Tue Sep 01 2020 barjac <barjac> 0.38.1-6.mga8
+ Revision: 1620668
- rebuild for gnuradio-3.8.2

* Sun Aug 23 2020 barjac <barjac> 0.38.1-5.mga8
+ Revision: 1618172
- fix build with patch sent upstream

* Wed Feb 19 2020 umeabot <umeabot> 0.38.1-4.mga8
+ Revision: 1544754
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 0.38.1-3.mga8
+ Revision: 1483377
- rebuild for boost 1.72.0

* Thu Jan 09 2020 barjac <barjac> 0.38.1-2.mga8
+ Revision: 1477391
- fix Source0
- create missing .pc in spec
- add it to spec and fix Url

* Wed Jan 08 2020 barjac <barjac> 0.38.1-1.mga8
+ Revision: 1477208
- new version 0.38.1
- new major 3
- adjust files list
+ wally <wally>
- build with new cmake macros

* Sat Jan 19 2019 barjac <barjac> 0.37.2-20.mga7
+ Revision: 1358110
- rebuild for gnuradio

* Tue Oct 16 2018 wally <wally> 0.37.2-19.mga7
+ Revision: 1321042
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 0.37.2-18.mga7
+ Revision: 1298079
- Mageia 7 Mass Rebuild

* Tue Jun 26 2018 barjac <barjac> 0.37.2-17.mga7
+ Revision: 1239935
- rebuild for gnuradio-3.7.13.3

* Mon Dec 25 2017 wally <wally> 0.37.2-16.mga7
+ Revision: 1184673
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 0.37.2-15.mga7
+ Revision: 1178324
- rebuild for boost 1.65

* Thu Oct 26 2017 barjac <barjac> 0.37.2-14.mga7
+ Revision: 1173817
- rebuild for arm

* Thu Oct 26 2017 barjac <barjac> 0.37.2-13.mga7
+ Revision: 1173800
- rebuild for boost/gnuradio

* Thu Sep 08 2016 barjac <barjac> 0.37.2-12.mga6
+ Revision: 1050496
- rebuild for gnuradio-3.7.10.1

* Wed Jul 27 2016 barjac <barjac> 0.37.2-11.mga6
+ Revision: 1043765
- rebuild for new gnuradio

* Wed Jul 27 2016 tmb <tmb> 0.37.2-10.mga6
+ Revision: 1043735
- rebuild for new gnuradio

* Thu Apr 14 2016 barjac <barjac> 0.37.2-9.mga6
+ Revision: 1001473
- rebuild for gnuradio

* Mon Feb 22 2016 barjac <barjac> 0.37.2-8.mga6
+ Revision: 976041
- rebuild for gnuradio

* Fri Feb 05 2016 umeabot <umeabot> 0.37.2-7.mga6
+ Revision: 937380
- Mageia 6 Mass Rebuild

* Thu Feb 04 2016 barjac <barjac> 0.37.2-6.mga6
+ Revision: 935396
- build for arm

* Thu Dec 31 2015 barjac <barjac> 0.37.2-5.mga6
+ Revision: 917213
- rebuild for gnuradio-3.7.9

* Sat Dec 26 2015 barjac <barjac> 0.37.2-4.mga6
+ Revision: 915207
- rebuild for boost-1.60.0

* Mon Dec 14 2015 barjac <barjac> 0.37.2-3.mga6
+ Revision: 910387
- rebuild for gnuradio-3.7.8.1

* Sat Sep 26 2015 barjac <barjac> 0.37.2-2.mga6
+ Revision: 883861
- rebuild for boost-1.59

* Sat Jan 17 2015 barjac <barjac> 0.37.2-1.mga6
+ Revision: 811115
- Import gr-iqbal - thanks to Fedora

